@@ -6,6 +6,7 @@ from datetime import date, datetime
 from flask import jsonify, request
 from flask.json import JSONEncoder
 from flask_wtf import FlaskForm
+from wtforms.validators import StopValidation
 
 from .utils import get_items
 
@@ -84,3 +85,47 @@ def validate(validate_form=None, upload=False):
         return wrapper
 
     return form_check
+
+
+def form_validate(validate_form=None, methods=["POST"]):
+    """
+    form validate decorator
+    """
+
+    def form_check(fn):
+        def wrapper(*args, **kwargs):
+            if request.method not in methods:
+                return fn(*args, **kwargs)
+
+            form = validate_form(
+                data=request.args if request.method == "GET" else get_json()
+            )
+            if not form.validate():
+                return response(code=999, msg=form.get_error_message())
+
+            kwargs.update({"form": form})
+            return fn(*args, **kwargs)
+
+        return wrapper
+
+    return form_check
+
+
+class NotEmpty(object):
+    field_flags = ("not_empty",)
+
+    def __init__(self, message=None):
+        self.message = message
+
+    def __call__(self, form, field):
+        if "password" not in field.name and isinstance(field.data, str):
+            field.data = field.data.strip()
+
+        if not field.data:
+            if self.message is None:
+                message = field.gettext("This field is be not empty.")
+            else:
+                message = self.message
+
+            field.errors[:] = []
+            raise StopValidation(message)
